
Deux versions de Foundation cohabitent dans ce répertoire. La version courante utilisée en frontend est Foundation 5.

Les éléments pour Foundation 3 restent en place si besoin car ils sont utilisés dans l'administration (comme CMS et Zinnia avec le ckeditor).

Fichiers CSS produits pour Foundation3
--------------------------------------

* **app.css** : Le fichier à utiliser sur le site en frontend, contient la mise en page complète selon le design fourni, produit avec Foundation5;
* **main.css** : Le fichier utilisable en frontend, produit avec Foundation3;
* **ckeditor.css** : Le fichier à utiliser pour l'éditeur CKEditor, contient une mise en page basique pour le contenu DANS l'éditeur, produit avec Foundation3;
* **minimal.css** : Une version basique de mise en page, en général reproduit tout le contenu possible de *main.css* mais sans l'entête et le pied de page, produit avec Foundation3;
